import {{application_name|title}}{{model_name|title}}Base from './base/{{application_name}}{{model_name}}';

class {{application_name|title}}{{model_name|title}} extends {{application_name|title}}{{model_name|title}}Base {

}

export default {{application_name|title}}{{model_name|title}};

// vim: backupcopy=yes
